@@ -21,6 +21,7 @@
 #include "config.h"
 #endif
 #include <string.h>
+#include <math.h>
 
 /* First, include the header file for the plugin, to bring in the
  * object definition and other useful things.
@@ -35,6 +36,16 @@
 #define PAL_BUFFER 144000
 #define PAL_FRAMERATE 25.0
 
+#define PAL_NORMAL_PAR_X	16
+#define PAL_NORMAL_PAR_Y	15
+#define PAL_WIDE_PAR_X		64
+#define PAL_WIDE_PAR_Y		45
+
+#define NTSC_NORMAL_PAR_X	80
+#define NTSC_NORMAL_PAR_Y	89
+#define NTSC_WIDE_PAR_X		320
+#define NTSC_WIDE_PAR_Y		267
+
 /* The ElementDetails structure gives a human-readable description
  * of the plugin, as well as author and version data.
  */
@@ -55,6 +66,9 @@ enum
   LAST_SIGNAL
 };
 
+#define DV_DEFAULT_QUALITY DV_QUALITY_BEST
+#define DV_DEFAULT_DECODE_NTH 1
+
 /* Arguments are identified the same way, but cannot be zero, so you
  * must leave the ARG_0 entry in as a placeholder.
  */
@@ -63,7 +77,8 @@ enum
   ARG_0,
   ARG_CLAMP_LUMA,
   ARG_CLAMP_CHROMA,
-  ARG_QUALITY
+  ARG_QUALITY,
+  ARG_DECODE_NTH
       /* FILL ME */
 };
 
@@ -76,8 +91,6 @@ const gint qualities[] = {
   DV_QUALITY_AC_2 | DV_QUALITY_COLOR
 };
 
-#define DV_QUALITY_DEFAULT 5
-
 /* The PadFactory structures describe what pads the element has or
  * can have.  They can be quite complex, but for this dvdec plugin
  * they are rather simple.
@@ -97,9 +110,15 @@ static GstStaticPadTemplate video_src_temp = GST_STATIC_PAD_TEMPLATE ("video",
         "height = (int) { "
         G_STRINGIFY (NTSC_HEIGHT) ", " G_STRINGIFY (PAL_HEIGHT)
         " }, "
-        "framerate = (double) { "
-        G_STRINGIFY (PAL_FRAMERATE) ", " G_STRINGIFY (NTSC_FRAMERATE)
-        " }; "
+        "pixel-aspect-ratio=(fraction) { "
+        G_STRINGIFY (PAL_NORMAL_PAR_X) "/" G_STRINGIFY (PAL_NORMAL_PAR_Y) ","
+        G_STRINGIFY (PAL_WIDE_PAR_X) "/" G_STRINGIFY (PAL_WIDE_PAR_Y) ","
+        G_STRINGIFY (NTSC_NORMAL_PAR_X) "/" G_STRINGIFY (NTSC_NORMAL_PAR_Y) ","
+        G_STRINGIFY (NTSC_WIDE_PAR_X) "/" G_STRINGIFY (NTSC_WIDE_PAR_Y) "},"
+        "framerate = (double) [ 1.0, 60.0 ];"
+        //"framerate = (double) { "
+        //G_STRINGIFY (PAL_FRAMERATE) ", " G_STRINGIFY (NTSC_FRAMERATE)
+        //" }; "
         "video/x-raw-rgb, "
         "bpp = (int) 32, "
         "depth = (int) 32, "
@@ -111,9 +130,15 @@ static GstStaticPadTemplate video_src_temp = GST_STATIC_PAD_TEMPLATE ("video",
         "height = (int) { "
         G_STRINGIFY (NTSC_HEIGHT) ", " G_STRINGIFY (PAL_HEIGHT)
         " }, "
-        "framerate = (double) { "
-        G_STRINGIFY (PAL_FRAMERATE) ", " G_STRINGIFY (NTSC_FRAMERATE)
-        " }; "
+        "pixel-aspect-ratio=(fraction) { "
+        G_STRINGIFY (PAL_NORMAL_PAR_X) "/" G_STRINGIFY (PAL_NORMAL_PAR_Y) ","
+        G_STRINGIFY (PAL_WIDE_PAR_X) "/" G_STRINGIFY (PAL_WIDE_PAR_Y) ","
+        G_STRINGIFY (NTSC_NORMAL_PAR_X) "/" G_STRINGIFY (NTSC_NORMAL_PAR_Y) ","
+        G_STRINGIFY (NTSC_WIDE_PAR_X) "/" G_STRINGIFY (NTSC_WIDE_PAR_Y) "},"
+        "framerate = (double) [ 1.0, 60.0 ];"
+        //"framerate = (double) { "
+        //G_STRINGIFY (PAL_FRAMERATE) ", " G_STRINGIFY (NTSC_FRAMERATE)
+        //" }; "
         "video/x-raw-rgb, "
         "bpp = (int) 24, "
         "depth = (int) 24, "
@@ -125,9 +150,16 @@ static GstStaticPadTemplate video_src_temp = GST_STATIC_PAD_TEMPLATE ("video",
         "height = (int) { "
         G_STRINGIFY (NTSC_HEIGHT) ", " G_STRINGIFY (PAL_HEIGHT)
         " }, "
-        "framerate = (double) { "
-        G_STRINGIFY (PAL_FRAMERATE) ", " G_STRINGIFY (NTSC_FRAMERATE)
-        " }")
+        "pixel-aspect-ratio=(fraction) { "
+        G_STRINGIFY (PAL_NORMAL_PAR_X) "/" G_STRINGIFY (PAL_NORMAL_PAR_Y) ","
+        G_STRINGIFY (PAL_WIDE_PAR_X) "/" G_STRINGIFY (PAL_WIDE_PAR_Y) ","
+        G_STRINGIFY (NTSC_NORMAL_PAR_X) "/" G_STRINGIFY (NTSC_NORMAL_PAR_Y) ","
+        G_STRINGIFY (NTSC_WIDE_PAR_X) "/" G_STRINGIFY (NTSC_WIDE_PAR_Y) "},"
+        "framerate = (double) [ 1.0, 60.0 ]"
+        //"framerate = (double) { "
+        //G_STRINGIFY (PAL_FRAMERATE) ", " G_STRINGIFY (NTSC_FRAMERATE)
+        //" }"
+    )
     );
 
 static GstStaticPadTemplate audio_src_temp = GST_STATIC_PAD_TEMPLATE ("audio",
@@ -284,7 +316,10 @@ gst_dvdec_class_init (GstDVDecClass * klass)
           FALSE, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_QUALITY,
       g_param_spec_enum ("quality", "Quality", "Decoding quality",
-          GST_TYPE_DVDEC_QUALITY, DV_QUALITY_DEFAULT, G_PARAM_READWRITE));
+          GST_TYPE_DVDEC_QUALITY, DV_DEFAULT_QUALITY, G_PARAM_READWRITE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_DECODE_NTH,
+      g_param_spec_int ("drop-factor", "Drop Factor", "Only decode Nth frame",
+          1, G_MAXINT, DV_DEFAULT_DECODE_NTH, G_PARAM_READWRITE));
 
   gobject_class->set_property = gst_dvdec_set_property;
   gobject_class->get_property = gst_dvdec_get_property;
@@ -366,10 +401,12 @@ gst_dvdec_init (GstDVDec * dvdec)
   dvdec->height = 0;
   dvdec->frequency = 0;
   dvdec->channels = 0;
+  dvdec->wide = FALSE;
+  dvdec->drop_factor = 1;
 
   dvdec->clamp_luma = FALSE;
   dvdec->clamp_chroma = FALSE;
-  dvdec->quality = DV_QUALITY_BEST;
+  dvdec->quality = DV_DEFAULT_QUALITY;
   dvdec->loop = FALSE;
 
   for (i = 0; i < 4; i++) {
@@ -620,6 +657,9 @@ gst_dvdec_handle_sink_event (GstDVDec * dvdec)
         gst_event_ref (event);
         gst_pad_push (dvdec->audiosrcpad, GST_DATA (event));
       }
+      if (type == GST_EVENT_EOS) {
+        gst_element_set_eos (GST_ELEMENT (dvdec));
+      }
       break;
     }
     case GST_EVENT_DISCONTINUOUS:
@@ -733,14 +773,33 @@ gst_dvdec_video_getcaps (GstPad * pad)
 
   if (dvdec->found_header) {
     int i;
+    gint par_x, par_y;
 
+    if (dvdec->PAL) {
+      if (dvdec->wide) {
+        par_x = PAL_WIDE_PAR_X;
+        par_y = PAL_WIDE_PAR_Y;
+      } else {
+        par_x = PAL_NORMAL_PAR_X;
+        par_y = PAL_NORMAL_PAR_Y;
+      }
+    } else {
+      if (dvdec->wide) {
+        par_x = NTSC_WIDE_PAR_X;
+        par_y = NTSC_WIDE_PAR_Y;
+      } else {
+        par_x = NTSC_NORMAL_PAR_X;
+        par_y = NTSC_NORMAL_PAR_Y;
+      }
+    }
     /* set the height */
     for (i = 0; i < gst_caps_get_size (caps); i++) {
       GstStructure *structure = gst_caps_get_structure (caps, i);
 
       gst_structure_set (structure,
           "height", G_TYPE_INT, dvdec->height,
-          "framerate", G_TYPE_DOUBLE, dvdec->framerate, NULL);
+          "framerate", G_TYPE_DOUBLE, dvdec->framerate / dvdec->drop_factor,
+          "pixel-aspect-ratio", GST_TYPE_FRACTION, par_x, par_y, NULL);
     }
   }
 
@@ -769,7 +828,9 @@ gst_dvdec_video_link (GstPad * pad, const GstCaps * caps)
       !gst_structure_get_double (structure, "framerate", &framerate))
     return GST_PAD_LINK_REFUSED;
 
-  if ((height != dvdec->height) || (framerate != dvdec->framerate))
+  /* allow a margin of error for the framerate caused by float rounding errors */
+  if ((height != dvdec->height) ||
+      (fabs (framerate - (dvdec->framerate / dvdec->drop_factor)) > 0.00000001))
     return GST_PAD_LINK_REFUSED;
 
   if (strcmp (gst_structure_get_name (structure), "video/x-raw-rgb") == 0) {
@@ -798,8 +859,6 @@ static void
 gst_dvdec_push (GstDVDec * dvdec, GstBuffer * outbuf, GstPad * pad,
     GstClockTime ts)
 {
-  GST_BUFFER_TIMESTAMP (outbuf) = ts;
-
   if ((dvdec->need_discont) || (dvdec->new_media)) {
     GstEvent *discont;
 
@@ -827,8 +886,9 @@ gst_dvdec_loop (GstElement * element)
   guint8 *inframe;
   gint height;
   guint32 length, got_bytes;
-  guint64 ts;
+  GstClockTime ts, duration;
   gdouble fps;
+  gboolean wide;
 
   dvdec = GST_DVDEC (element);
 
@@ -859,6 +919,7 @@ gst_dvdec_loop (GstElement * element)
   fps = (dvdec->PAL ? PAL_FRAMERATE : NTSC_FRAMERATE);
   height = (dvdec->PAL ? PAL_HEIGHT : NTSC_HEIGHT);
   length = (dvdec->PAL ? PAL_BUFFER : NTSC_BUFFER);
+  wide = dv_format_wide (dvdec->decoder);
 
   if (length != dvdec->length) {
     dvdec->length = length;
@@ -873,14 +934,14 @@ gst_dvdec_loop (GstElement * element)
   }
 
   ts = dvdec->next_ts;
-  dvdec->next_ts += GST_SECOND / dvdec->framerate;
+  dvdec->next_ts += GST_SECOND / fps;
+  duration = dvdec->next_ts - ts;
 
   dv_parse_packs (dvdec->decoder, GST_BUFFER_DATA (buf));
   if (dv_is_new_recording (dvdec->decoder, GST_BUFFER_DATA (buf)))
     dvdec->new_media = TRUE;
   if (GST_PAD_IS_LINKED (dvdec->audiosrcpad)) {
-    gint16 *a_ptr;
-    gint i, j;
+    gint num_samples;
 
     dv_decode_full_audio (dvdec->decoder, GST_BUFFER_DATA (buf),
         dvdec->audio_buffers);
@@ -905,7 +966,12 @@ gst_dvdec_loop (GstElement * element)
       dvdec->channels = dv_get_num_channels (dvdec->decoder);
     }
 
-    if (dv_get_num_samples (dvdec->decoder) > 0) {
+    num_samples = dv_get_num_samples (dvdec->decoder);
+
+    if (num_samples) {
+      gint16 *a_ptr;
+      gint i, j;
+
       outbuf = gst_buffer_new ();
       GST_BUFFER_SIZE (outbuf) = dv_get_num_samples (dvdec->decoder) *
           sizeof (gint16) * dv_get_num_channels (dvdec->decoder);
@@ -913,11 +979,18 @@ gst_dvdec_loop (GstElement * element)
 
       a_ptr = (gint16 *) GST_BUFFER_DATA (outbuf);
 
-      for (i = 0; i < dv_get_num_samples (dvdec->decoder); i++) {
+      for (i = 0; i < num_samples; i++) {
         for (j = 0; j < dv_get_num_channels (dvdec->decoder); j++) {
           *(a_ptr++) = dvdec->audio_buffers[j][i];
         }
       }
+
+      GST_BUFFER_TIMESTAMP (outbuf) = ts;
+      GST_BUFFER_DURATION (outbuf) = duration;
+      GST_BUFFER_OFFSET (outbuf) = dvdec->audio_offset;
+      dvdec->audio_offset += num_samples;
+      GST_BUFFER_OFFSET_END (outbuf) = dvdec->audio_offset;
+
       gst_dvdec_push (dvdec, outbuf, dvdec->audiosrcpad, ts);
     }
   } else {
@@ -930,9 +1003,18 @@ gst_dvdec_loop (GstElement * element)
     guint8 *outframe_ptrs[3];
     gint outframe_pitches[3];
 
-    if ((dvdec->framerate != fps) || (dvdec->height != height)) {
+    dvdec->framecount++;
+    if (dvdec->framecount < dvdec->drop_factor) {
+      /* don't decode */
+      goto end;
+    }
+    dvdec->framecount = 0;
+
+    if ((dvdec->framerate != fps) || (dvdec->height != height)
+        || dvdec->wide != wide) {
       dvdec->height = height;
       dvdec->framerate = fps;
+      dvdec->wide = wide;
 
       if (GST_PAD_LINK_FAILED (gst_pad_renegotiate (dvdec->videosrcpad))) {
         GST_ELEMENT_ERROR (dvdec, CORE, NEGOTIATION, (NULL), (NULL));
@@ -959,12 +1041,17 @@ gst_dvdec_loop (GstElement * element)
     dv_decode_full_frame (dvdec->decoder, GST_BUFFER_DATA (buf),
         dvdec->space, outframe_ptrs, outframe_pitches);
 
+    GST_BUFFER_TIMESTAMP (outbuf) = ts;
+    GST_BUFFER_DURATION (outbuf) = duration * dvdec->drop_factor;
+
     gst_dvdec_push (dvdec, outbuf, dvdec->videosrcpad, ts);
   } else {
     dvdec->height = height;
     dvdec->framerate = fps;
+    dvdec->wide = wide;
   }
 
+end:
   if ((dvdec->end_position != -1) &&
       (dvdec->next_ts >= dvdec->end_position) && !dvdec->loop) {
     gst_element_set_eos (GST_ELEMENT (dvdec));
@@ -989,6 +1076,8 @@ gst_dvdec_change_state (GstElement * element)
       dvdec->decoder =
           dv_decoder_new (0, dvdec->clamp_luma, dvdec->clamp_chroma);
       dvdec->decoder->quality = qualities[dvdec->quality];
+      dvdec->audio_offset = 0;
+      dvdec->framecount = 0;
       /* 
        * Enable this function call when libdv2 0.100 or higher is more
        * common
@@ -1043,6 +1132,9 @@ gst_dvdec_set_property (GObject * object, guint prop_id, const GValue * value,
       if ((dvdec->quality < 0) || (dvdec->quality > 5))
         dvdec->quality = 0;
       break;
+    case ARG_DECODE_NTH:
+      dvdec->drop_factor = g_value_get_int (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1070,6 +1162,9 @@ gst_dvdec_get_property (GObject * object, guint prop_id, GValue * value,
     case ARG_QUALITY:
       g_value_set_enum (value, dvdec->quality);
       break;
+    case ARG_DECODE_NTH:
+      g_value_set_int (value, dvdec->drop_factor);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
