@@ -51,7 +51,7 @@ static GstStaticPadTemplate sink_factory = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("audio/x-raw-int, "
-        "endianess = (int) BYTE_ORDER, "
+        "endianness = (int) BYTE_ORDER, "
         "signed = (boolean) TRUE, "
         "width = (int) 16, "
         "depth = (int) 16, "
@@ -67,6 +67,7 @@ static GstStaticPadTemplate sink_factory = GST_STATIC_PAD_TEMPLATE ("sink",
 static void gst_nassink_base_init (gpointer g_class);
 static void gst_nassink_class_init (GstNassinkClass * klass);
 static void gst_nassink_init (GstNassink * nassink);
+static void gst_nassink_finalize (GObject * object);
 
 static gboolean gst_nassink_open_audio (GstNassink * sink);
 static void gst_nassink_close_audio (GstNassink * sink);
@@ -152,6 +153,7 @@ gst_nassink_class_init (GstNassinkClass * klass)
 
   gobject_class->set_property = gst_nassink_set_property;
   gobject_class->get_property = gst_nassink_get_property;
+  gobject_class->finalize = gst_nassink_finalize;
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MUTE, g_param_spec_boolean ("mute", "mute", "mute", TRUE, G_PARAM_READWRITE));   /* CHECKME */
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_HOST, g_param_spec_string ("host", "host", "host", NULL, G_PARAM_READWRITE));    /* CHECKME */
@@ -187,6 +189,15 @@ gst_nassink_init (GstNassink * nassink)
   nassink->buf = NULL;
 }
 
+static void
+gst_nassink_finalize (GObject * object)
+{
+  GstNassink *nassink = GST_NASSINK (object);
+
+  g_free (nassink->host);
+  G_OBJECT_CLASS (parent_class)->finalize (object);
+}
+
 static GstCaps *
 gst_nassink_getcaps (GstPad * pad)
 {
