@@ -17,9 +17,6 @@
 
 #include "polypsink.h"
 
-GST_DEBUG_CATEGORY_EXTERN (polyp_debug);
-#define GST_CAT_DEFAULT polyp_debug
-
 enum
 {
   ARG_0,
@@ -47,6 +44,17 @@ gst_polypsink_base_init (gpointer g_class)
           "signed = (boolean) TRUE, "
           "width = (int) 16, "
           "depth = (int) 16, "
+          "rate = (int) [ 1, MAX ], "
+          "channels = (int) [ 1, 16 ];"
+          "audio/x-raw-float, "
+          "endianness = (int) { LITTLE_ENDIAN, BIG_ENDIAN }, "
+          "width = (int) 32, "
+          "rate = (int) [ 1, MAX ], "
+          "channels = (int) [ 1, 16 ];"
+          "audio/x-raw-int, "
+          "signed = (boolean) FALSE, "
+          "width = (int) 8, "
+          "depth = (int) 8, "
           "rate = (int) [ 1, MAX ], " "channels = (int) [ 1, 16 ]")
       );
 
@@ -231,7 +239,6 @@ stream_state_callback (struct pa_stream *s, void *userdata)
       /* Pass over */
     case PA_STREAM_TERMINATED:
     default:
-      GST_DEBUG ("stream terminated");
       polypsink->mainloop_api->quit (polypsink->mainloop_api, 1);
       destroy_context (polypsink);
       break;
@@ -272,7 +279,6 @@ context_state_callback (struct pa_context *c, void *userdata)
       /* Pass over */
     case PA_CONTEXT_TERMINATED:
     default:
-      GST_DEBUG ("stream terminated");
       polypsink->mainloop_api->quit (polypsink->mainloop_api, 1);
       destroy_context (polypsink);
       break;
@@ -328,11 +334,7 @@ create_context (GstPolypSink * polypsink)
 
   pa_context_set_state_callback (polypsink->context, context_state_callback,
       polypsink);
-  if (polypsink->server && polypsink->server[0]) {
-    pa_context_connect (polypsink->context, polypsink->server, 1, NULL);
-  } else {
-    pa_context_connect (polypsink->context, NULL, 1, NULL);
-  }
+  pa_context_connect (polypsink->context, NULL, 1, NULL);
 }
 
 static void
@@ -490,8 +492,6 @@ gst_polypsink_link (GstPad * pad, const GstCaps * caps)
   const char *n;
   char t[256];
   GstElementState state;
-  int n_channels;
-  int tmp;
 
   polypsink = GST_POLYPSINK (gst_pad_get_parent (pad));
 
@@ -519,30 +519,24 @@ gst_polypsink_link (GstPad * pad, const GstCaps * caps)
   else if (depth == 32 && endianness == 4321
       && !strcmp (n, "audio/x-raw-float"))
     polypsink->sample_spec.format = PA_SAMPLE_FLOAT32LE;
-  else {
-    GST_DEBUG ("unrecognized format, refusing link");
+  else
     return GST_PAD_LINK_REFUSED;
-  }
-
-  GST_DEBUG ("using format %d", polypsink->sample_spec.format);
 
   polypsink->sample_spec.rate = 44100;
   polypsink->sample_spec.channels = 2;
 
   pa_sample_spec_snprint (t, sizeof (t), &polypsink->sample_spec);
 
-  gst_structure_get_int (structure, "channels", &n_channels);
-  polypsink->sample_spec.channels = n_channels;
-  gst_structure_get_int (structure, "rate", &tmp);
-  polypsink->sample_spec.rate = tmp;
+  gst_structure_get_int (structure, "channels",
+      (int *) &polypsink->sample_spec.channels);
+  gst_structure_get_int (structure, "rate", &polypsink->sample_spec.rate);
 
   pa_sample_spec_snprint (t, sizeof (t), &polypsink->sample_spec);
-  GST_DEBUG ("using format %s", t);
 
-  if (!pa_sample_spec_valid (&polypsink->sample_spec)) {
-    GST_DEBUG ("invalid format, refusing link");
+  if (!pa_sample_spec_valid (&polypsink->sample_spec))
     return GST_PAD_LINK_REFUSED;
-  }
+
+
 
   polypsink->negotiated = 1;
 
