@@ -30,13 +30,16 @@
 #include <gst/tag/tag.h>
 #include "vorbisenc.h"
 
+GST_DEBUG_CATEGORY_EXTERN (vorbisenc_debug);
+#define GST_CAT_DEFAULT vorbisenc_debug
+
 static GstPadTemplate *gst_vorbisenc_src_template, *gst_vorbisenc_sink_template;
 
 /* elementfactory information */
 GstElementDetails vorbisenc_details = {
-  "Ogg Vorbis encoder",
+  "Vorbis encoder",
   "Codec/Encoder/Audio",
-  "Encodes audio in OGG Vorbis format",
+  "Encodes audio in Vorbis format",
   "Monty <monty@xiph.org>, " "Wim Taymans <wim@fluendo.com>",
 };
 
@@ -93,6 +96,8 @@ gst_vorbisenc_get_formats (GstPad * pad)
 #define BITRATE_DEFAULT 	-1
 #define MIN_BITRATE_DEFAULT 	-1
 #define QUALITY_DEFAULT 	0.3
+#define LOWEST_BITRATE 		6000    /* lowest allowed for a 8 kHz stream */
+#define HIGHEST_BITRATE 	250001  /* highest allowed for a 44 kHz stream */
 
 static void gst_vorbisenc_base_init (gpointer g_class);
 static void gst_vorbisenc_class_init (VorbisEncClass * klass);
@@ -153,12 +158,14 @@ vorbis_caps_factory (void)
 static GstCaps *
 raw_caps_factory (void)
 {
+  /* lowest sample rate is in vorbis/lib/modes/setup_8.h, 8000 Hz
+   * highest sample rate is in vorbis/lib/modes/setup_44.h, 50000 Hz */
   return
       gst_caps_new_simple ("audio/x-raw-float",
+      "rate", GST_TYPE_INT_RANGE, 8000, 50000,
+      "channels", GST_TYPE_INT_RANGE, 1, 2,
       "endianness", G_TYPE_INT, G_BYTE_ORDER,
-      "width", G_TYPE_INT, 32,
-      "rate", GST_TYPE_INT_RANGE, 11025, 48000,
-      "channels", GST_TYPE_INT_RANGE, 1, 2, NULL);
+      "width", G_TYPE_INT, 32, "buffer-frames", G_TYPE_INT, 0, NULL);
 }
 
 static void
@@ -191,17 +198,21 @@ gst_vorbisenc_class_init (VorbisEncClass * klass)
   gstelement_class = (GstElementClass *) klass;
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MAX_BITRATE,
-      g_param_spec_int ("max_bitrate", "Max bitrate",
-          " Specify a minimum bitrate (in bps). Useful for encoding for a fixed-size channel",
-          -1, G_MAXINT, MAX_BITRATE_DEFAULT, G_PARAM_READWRITE));
+      g_param_spec_int ("max-bitrate", "Maximum Bitrate",
+          "Specify a maximum bitrate (in bps). Useful for streaming "
+          "applications. (-1 == disabled)",
+          -1, HIGHEST_BITRATE, MAX_BITRATE_DEFAULT, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_BITRATE,
-      g_param_spec_int ("bitrate", "Bitrate", "Choose a bitrate to encode at. "
-          "Attempt to encode at a bitrate averaging this. Takes an argument in kbps.",
-          -1, G_MAXINT, BITRATE_DEFAULT, G_PARAM_READWRITE));
+      g_param_spec_int ("bitrate", "Target Bitrate",
+          "Attempt to encode at a bitrate averaging this (in bps). "
+          "This uses the bitrate management engine, and is not recommended for most users. "
+          "Quality is a better alternative. (-1 == disabled)",
+          -1, HIGHEST_BITRATE, BITRATE_DEFAULT, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MIN_BITRATE,
-      g_param_spec_int ("min_bitrate", "Min bitrate",
-          "Specify a maximum bitrate in bps. Useful for streaming applications.",
-          -1, G_MAXINT, MIN_BITRATE_DEFAULT, G_PARAM_READWRITE));
+      g_param_spec_int ("min_bitrate", "Minimum Bitrate",
+          "Specify a minimum bitrate (in bps). Useful for encoding for a "
+          "fixed-size channel. (-1 == disabled)",
+          -1, HIGHEST_BITRATE, MIN_BITRATE_DEFAULT, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_QUALITY,
       g_param_spec_float ("quality", "Quality",
           "Specify quality instead of specifying a particular bitrate.",
@@ -494,21 +505,24 @@ gst_vorbisenc_get_tag_value (const GstTagList * list, const gchar * tag,
       || (strcmp (tag, GST_TAG_ALBUM_VOLUME_COUNT) == 0)) {
     guint track_no;
 
-    g_assert (gst_tag_list_get_uint_index (list, tag, index, &track_no));
+    if (!gst_tag_list_get_uint_index (list, tag, index, &track_no))
+      g_assert_not_reached ();
     vorbisvalue = g_strdup_printf ("%u", track_no);
   } else if (strcmp (tag, GST_TAG_DATE) == 0) {
     /* FIXME: how are dates represented in vorbis files? */
     GDate *date;
     guint u;
 
-    g_assert (gst_tag_list_get_uint_index (list, tag, index, &u));
+    if (!gst_tag_list_get_uint_index (list, tag, index, &u))
+      g_assert_not_reached ();
     date = g_date_new_julian (u);
     vorbisvalue =
         g_strdup_printf ("%04d-%02d-%02d", (gint) g_date_get_year (date),
         (gint) g_date_get_month (date), (gint) g_date_get_day (date));
     g_date_free (date);
   } else if (gst_tag_get_type (tag) == G_TYPE_STRING) {
-    g_assert (gst_tag_list_get_string_index (list, tag, index, &vorbisvalue));
+    if (!gst_tag_list_get_string_index (list, tag, index, &vorbisvalue))
+      g_assert_not_reached ();
   }
 
   return vorbisvalue;
@@ -652,7 +666,8 @@ gst_vorbisenc_setup (VorbisEnc * vorbisenc)
 
       vorbis_encode_ctl (&vorbisenc->vi, OV_ECTL_RATEMANAGE_GET, &ai);
 
-      /* the bitrates are in kHz */
+      /* the bitrates used by libvorbisenc are in kbit/sec, ours in bit/sec
+       * also remember that in telecom kbit/sec is 1000 bit/sec */
       ai.bitrate_hard_min = vorbisenc->min_bitrate / 1000;
       ai.bitrate_hard_max = vorbisenc->max_bitrate / 1000;
       ai.management_active = 1;
@@ -660,14 +675,20 @@ gst_vorbisenc_setup (VorbisEnc * vorbisenc)
       vorbis_encode_ctl (&vorbisenc->vi, OV_ECTL_RATEMANAGE_SET, &ai);
     }
   } else {
+    long min_bitrate, max_bitrate;
+
+    min_bitrate = vorbisenc->min_bitrate > 0 ? vorbisenc->min_bitrate : -1;
+    max_bitrate = vorbisenc->max_bitrate > 0 ? vorbisenc->max_bitrate : -1;
+
     if (vorbis_encode_setup_managed (&vorbisenc->vi,
             vorbisenc->channels,
             vorbisenc->frequency,
-            vorbisenc->max_bitrate > 0 ? vorbisenc->max_bitrate : -1,
-            vorbisenc->bitrate,
-            vorbisenc->min_bitrate > 0 ? vorbisenc->min_bitrate : -1)) {
+            max_bitrate, vorbisenc->bitrate, min_bitrate) != 0) {
       GST_ERROR_OBJECT (vorbisenc,
-          "vorbisenc: initialisation failed: invalid parameters for bitrate");
+          "vorbis_encode_setup_managed "
+          "(c %d, rate %d, max br %ld, br %ld, min br %ld) failed",
+          vorbisenc->channels, vorbisenc->frequency, max_bitrate,
+          vorbisenc->bitrate, min_bitrate);
       vorbis_info_clear (&vorbisenc->vi);
       return FALSE;
     }
@@ -952,6 +973,11 @@ gst_vorbisenc_set_property (GObject * object, guint prop_id,
       gboolean old_value = vorbisenc->managed;
 
       vorbisenc->max_bitrate = g_value_get_int (value);
+      if (vorbisenc->max_bitrate >= 0
+          && vorbisenc->max_bitrate < LOWEST_BITRATE) {
+        g_warning ("Lowest allowed bitrate is %d", LOWEST_BITRATE);
+        vorbisenc->max_bitrate = LOWEST_BITRATE;
+      }
       if (vorbisenc->min_bitrate > 0 && vorbisenc->max_bitrate > 0)
         vorbisenc->managed = TRUE;
       else
@@ -963,12 +989,21 @@ gst_vorbisenc_set_property (GObject * object, guint prop_id,
     }
     case ARG_BITRATE:
       vorbisenc->bitrate = g_value_get_int (value);
+      if (vorbisenc->bitrate >= 0 && vorbisenc->bitrate < LOWEST_BITRATE) {
+        g_warning ("Lowest allowed bitrate is %d", LOWEST_BITRATE);
+        vorbisenc->bitrate = LOWEST_BITRATE;
+      }
       break;
     case ARG_MIN_BITRATE:
     {
       gboolean old_value = vorbisenc->managed;
 
       vorbisenc->min_bitrate = g_value_get_int (value);
+      if (vorbisenc->min_bitrate >= 0
+          && vorbisenc->min_bitrate < LOWEST_BITRATE) {
+        g_warning ("Lowest allowed bitrate is %d", LOWEST_BITRATE);
+        vorbisenc->min_bitrate = LOWEST_BITRATE;
+      }
       if (vorbisenc->min_bitrate > 0 && vorbisenc->max_bitrate > 0)
         vorbisenc->managed = TRUE;
       else
