@@ -136,6 +136,7 @@ gst_riff_create_video_caps_with_data (guint32 codec_fcc,
       break;
 
     case GST_MAKE_FOURCC ('M', '2', '6', '3'):
+    case GST_MAKE_FOURCC ('m', '2', '6', '3'):
       caps = gst_caps_new_simple ("video/x-h263", NULL);
       if (codec_name)
         *codec_name = g_strdup ("Microsoft H.263");
@@ -159,6 +160,18 @@ gst_riff_create_video_caps_with_data (guint32 codec_fcc,
         *codec_name = g_strdup ("Xirlink H.263");
       break;
 
+    case GST_MAKE_FOURCC ('h', '2', '6', '4'):
+      caps = gst_caps_new_simple ("video/x-h264", NULL);
+      if (codec_name)
+        *codec_name = g_strdup ("ITU H.264");
+      break;
+
+    case GST_MAKE_FOURCC ('V', 'S', 'S', 'H'):
+      caps = gst_caps_new_simple ("video/x-h264", NULL);
+      if (codec_name)
+        *codec_name = g_strdup ("VideoSoft H.264");
+      break;
+
     case GST_MAKE_FOURCC ('D', 'I', 'V', '3'):
     case GST_MAKE_FOURCC ('d', 'i', 'v', '3'):
     case GST_MAKE_FOURCC ('D', 'I', 'V', '4'):
@@ -181,6 +194,13 @@ gst_riff_create_video_caps_with_data (guint32 codec_fcc,
         *codec_name = g_strdup ("DivX MPEG-4 Version 4");
       break;
 
+    case GST_MAKE_FOURCC ('B', 'L', 'Z', '0'):
+      caps = gst_caps_new_simple ("video/x-divx",
+          "divxversion", G_TYPE_INT, 4, NULL);
+      if (codec_name)
+        *codec_name = g_strdup ("Blizzard DivX");
+      break;
+
     case GST_MAKE_FOURCC ('D', 'X', '5', '0'):
       caps = gst_caps_new_simple ("video/x-divx",
           "divxversion", G_TYPE_INT, 5, NULL);
@@ -297,6 +317,13 @@ gst_riff_create_video_caps_with_data (guint32 codec_fcc,
         *codec_name = g_strdup ("Xan Wing Commander 4");
       break;
 
+    case GST_MAKE_FOURCC ('I', 'V', '5', '0'):
+      caps = gst_caps_new_simple ("video/x-intel",
+          "ivversion", G_TYPE_INT, 5, NULL);
+      if (codec_name)
+        *codec_name = g_strdup ("Intel Video 5");
+      break;
+
     default:
       GST_WARNING ("Unknown video fourcc " GST_FOURCC_FORMAT,
           GST_FOURCC_ARGS (codec_fcc));
@@ -507,7 +534,7 @@ gst_riff_create_audio_caps_with_data (guint16 codec_id,
     }
     if (block_align) {
       gst_caps_set_simple (caps,
-          "block_align", GST_TYPE_INT_RANGE, 1, 8192, NULL);
+          "block_align", GST_TYPE_INT_RANGE, 1, G_MAXINT, NULL);
     }
   }
 
@@ -575,6 +602,7 @@ gst_riff_create_video_template_caps (void)
     GST_MAKE_FOURCC ('D', 'I', 'V', '3'),
     GST_MAKE_FOURCC ('M', 'P', 'E', 'G'),
     GST_MAKE_FOURCC ('H', '2', '6', '3'),
+    GST_MAKE_FOURCC ('h', '2', '6', '4'),
     GST_MAKE_FOURCC ('D', 'I', 'V', 'X'),
     GST_MAKE_FOURCC ('D', 'X', '5', '0'),
     GST_MAKE_FOURCC ('X', 'V', 'I', 'D'),
@@ -584,6 +612,7 @@ gst_riff_create_video_template_caps (void)
     GST_MAKE_FOURCC ('R', 'L', 'E', ' '),
     GST_MAKE_FOURCC ('D', 'I', 'B', ' '),
     GST_MAKE_FOURCC ('X', 'x', 'a', 'n'),
+    GST_MAKE_FOURCC ('I', 'V', '5', '0'),
     /* FILL ME */
     0
   };
