@@ -70,8 +70,8 @@ enum
 
 enum
 {
-  ARG_0,
-  /* FILL ME */
+  ARG_0
+      /* FILL ME */
 };
 
 static void gst_mp1videoparse_class_init (Mp1VideoParseClass * klass);
@@ -106,6 +106,7 @@ mp1videoparse_get_type (void)
       0,
       (GInstanceInitFunc) gst_mp1videoparse_init,
     };
+
     mp1videoparse_type =
         g_type_register_static (GST_TYPE_ELEMENT, "Mp1VideoParse",
         &mp1videoparse_info, 0);
@@ -154,6 +155,7 @@ gst_mp1videoparse_init (Mp1VideoParse * mp1videoparse)
 
   mp1videoparse->partialbuf = NULL;
   mp1videoparse->need_resync = FALSE;
+  mp1videoparse->need_discont = TRUE;
   mp1videoparse->last_pts = GST_CLOCK_TIME_NONE;
   mp1videoparse->picture_in_buffer = 0;
   mp1videoparse->width = mp1videoparse->height = -1;
@@ -173,7 +175,7 @@ mp1videoparse_parse_seq (Mp1VideoParse * mp1videoparse, GstBuffer * buf)
     30. / 1.001, 30.,
     50., 60. / 1.001, 60.
   };
-  guint32 n = GUINT32_FROM_BE (*(guint32 *) GST_BUFFER_DATA (buf));
+  guint32 n = GST_READ_UINT32_BE (GST_BUFFER_DATA (buf));
 
   width = (n & 0xfff00000) >> 20;
   height = (n & 0x000fff00) >> 8;
@@ -275,7 +277,7 @@ mp1videoparse_find_next_gop (Mp1VideoParse * mp1videoparse, GstBuffer * buf)
 static guint64
 gst_mp1videoparse_time_code (guchar * gop, gfloat fps)
 {
-  guint32 data = GUINT32_FROM_BE (*(guint32 *) gop);
+  guint32 data = GST_READ_UINT32_BE (gop);
 
   return ((((data & 0xfc000000) >> 26) * 3600 * GST_SECOND) +   /* hours */
       (((data & 0x03f00000) >> 20) * 60 * GST_SECOND) + /* minutes */
@@ -332,8 +334,10 @@ gst_mp1videoparse_real_chain (Mp1VideoParse * mp1videoparse, GstBuffer * buf,
     GstEvent *event = GST_EVENT (buf);
 
     switch (GST_EVENT_TYPE (event)) {
-      case GST_EVENT_FLUSH:
       case GST_EVENT_DISCONTINUOUS:
+        mp1videoparse->need_discont = TRUE;
+        /* fall-through */
+      case GST_EVENT_FLUSH:
         gst_mp1videoparse_flush (mp1videoparse);
         break;
       case GST_EVENT_EOS:
@@ -377,7 +381,7 @@ gst_mp1videoparse_real_chain (Mp1VideoParse * mp1videoparse, GstBuffer * buf,
     data = GST_BUFFER_DATA (mp1videoparse->partialbuf);
     size = GST_BUFFER_SIZE (mp1videoparse->partialbuf);
 
-    head = GUINT32_FROM_BE (*((guint32 *) data));
+    head = GST_READ_UINT32_BE (data);
 
     GST_DEBUG ("mp1videoparse: head is %08x", (unsigned int) head);
 
@@ -402,7 +406,7 @@ gst_mp1videoparse_real_chain (Mp1VideoParse * mp1videoparse, GstBuffer * buf,
           offset = 0;
         }
 
-        head = GUINT32_FROM_BE (*((guint32 *) data));
+        head = GST_READ_UINT32_BE (data);
         /* re-call this function so that if we hadn't already, we can
          * now read the sequence header and parse video properties,
          * set caps, stream data, be happy, bla, bla, bla... */
@@ -480,16 +484,16 @@ gst_mp1videoparse_real_chain (Mp1VideoParse * mp1videoparse, GstBuffer * buf,
       /* something else... */
       else
         sync_state = 0;
+
       /* go down the buffer */
       offset++;
     }
 
     if (have_sync) {
       offset -= 2;
-      GST_DEBUG ("mp1videoparse: synced at %ld code 0x000001%02x", offset,
-          data[offset + 3]);
+      GST_DEBUG ("mp1videoparse: synced");
 
-      outbuf = gst_buffer_create_sub (mp1videoparse->partialbuf, 0, offset + 4);
+      outbuf = gst_buffer_create_sub (mp1videoparse->partialbuf, 0, offset);
       g_assert (outbuf != NULL);
       GST_BUFFER_TIMESTAMP (outbuf) = mp1videoparse->last_pts;
       GST_BUFFER_DURATION (outbuf) = GST_SECOND / mp1videoparse->fps;
@@ -501,6 +505,16 @@ gst_mp1videoparse_real_chain (Mp1VideoParse * mp1videoparse, GstBuffer * buf,
       }
 
       if (GST_PAD_CAPS (outpad) != NULL) {
+        if (mp1videoparse->need_discont &&
+            GST_BUFFER_TIMESTAMP_IS_VALID (outbuf)) {
+          GstEvent *event = gst_event_new_discontinuous (FALSE,
+              GST_FORMAT_TIME, GST_BUFFER_TIMESTAMP (outbuf),
+              GST_FORMAT_UNDEFINED);
+
+          GST_DEBUG ("prepending discont event");
+          gst_pad_push (outpad, GST_DATA (event));
+          mp1videoparse->need_discont = FALSE;
+        }
         GST_DEBUG ("mp1videoparse: pushing  %d bytes %" G_GUINT64_FORMAT,
             GST_BUFFER_SIZE (outbuf), GST_BUFFER_TIMESTAMP (outbuf));
         gst_pad_push (outpad, GST_DATA (outbuf));
@@ -511,19 +525,22 @@ gst_mp1videoparse_real_chain (Mp1VideoParse * mp1videoparse, GstBuffer * buf,
       }
       mp1videoparse->picture_in_buffer = 0;
 
-      temp =
-          gst_buffer_create_sub (mp1videoparse->partialbuf, offset,
-          size - offset);
+      if (size != offset) {
+        temp =
+            gst_buffer_create_sub (mp1videoparse->partialbuf, offset,
+            size - offset);
+      } else {
+        temp = NULL;
+      }
       gst_buffer_unref (mp1videoparse->partialbuf);
       mp1videoparse->partialbuf = temp;
       offset = 0;
     } else {
-      if (time_stamp != GST_CLOCK_TIME_NONE) {
+      if (time_stamp != GST_CLOCK_TIME_NONE)
         mp1videoparse->last_pts = time_stamp;
-        break;
-      }
+      return;
     }
-  } while (1);
+  } while (mp1videoparse->partialbuf != NULL);
 }
 
 static GstElementStateReturn
@@ -538,6 +555,7 @@ gst_mp1videoparse_change_state (GstElement * element)
   switch (GST_STATE_TRANSITION (element)) {
     case GST_STATE_PAUSED_TO_READY:
       gst_mp1videoparse_flush (mp1videoparse);
+      mp1videoparse->need_discont = TRUE;
       mp1videoparse->width = mp1videoparse->height = -1;
       mp1videoparse->fps = mp1videoparse->asr = 0.;
       break;
