@@ -242,7 +242,8 @@ gst_decode_bin_factory_filter (GstPluginFeature * feature,
 
   klass = gst_element_factory_get_klass (GST_ELEMENT_FACTORY (feature));
   /* only demuxers and decoders can play */
-  if (strstr (klass, "Demux") == NULL && strstr (klass, "Decoder") == NULL) {
+  if (strstr (klass, "Demux") == NULL &&
+      strstr (klass, "Decoder") == NULL && strstr (klass, "Parse") == NULL) {
     return FALSE;
   }
 
@@ -258,7 +259,13 @@ gst_decode_bin_factory_filter (GstPluginFeature * feature,
 static gint
 compare_ranks (GstPluginFeature * f1, GstPluginFeature * f2)
 {
-  return gst_plugin_feature_get_rank (f2) - gst_plugin_feature_get_rank (f1);
+  gint diff;
+
+  diff = gst_plugin_feature_get_rank (f2) - gst_plugin_feature_get_rank (f1);
+  if (diff != 0)
+    return diff;
+  return strcmp (gst_plugin_feature_get_name (f2),
+      gst_plugin_feature_get_name (f1));
 }
 
 static void
@@ -363,6 +370,8 @@ find_compatibles (GstDecodeBin * decode_bin, const GstCaps * caps)
         if (!gst_caps_is_empty (intersect)) {
           /* non empty intersection, we can use this element */
           to_try = g_list_append (to_try, factory);
+          gst_caps_free (intersect);
+          break;
         }
         gst_caps_free (intersect);
       }
@@ -636,11 +645,15 @@ static void
 new_pad (GstElement * element, GstPad * pad, GstDynamic * dynamic)
 {
   GstDecodeBin *decode_bin = dynamic->decode_bin;
+  GstCaps *caps;
 
   /* see if any more pending dynamic connections exist */
   gboolean more = gst_decode_bin_is_dynamic (decode_bin);
 
-  close_pad_link (element, pad, gst_pad_get_caps (pad), decode_bin, more);
+  caps = gst_pad_get_caps (pad);
+  close_pad_link (element, pad, caps, decode_bin, more);
+  if (caps)
+    gst_caps_free (caps);
 }
 
 /* this signal is fired when an element signals the no_more_pads signal.
@@ -812,6 +825,7 @@ close_link (GstElement * element, GstDecodeBin * decode_bin)
   /* now loop over all the pads we need to connect */
   for (pads = to_connect; pads; pads = g_list_next (pads)) {
     GstPad *pad = GST_PAD (pads->data);
+    GstCaps *caps;
 
     /* we have more pads if we have more than 1 pad to connect or
      * dynamics. If we have only 1 pad and no dynamics, more will be
@@ -823,7 +837,10 @@ close_link (GstElement * element, GstDecodeBin * decode_bin)
         gst_pad_get_name (pad));
 
     /* continue autoplugging on the pads */
-    close_pad_link (element, pad, gst_pad_get_caps (pad), decode_bin, more);
+    caps = gst_pad_get_caps (pad);
+    close_pad_link (element, pad, caps, decode_bin, more);
+    if (caps)
+      gst_caps_free (caps);
   }
 
   g_list_free (to_connect);
