@@ -62,9 +62,6 @@ struct _GstPlayBin
 
   /* our cache for the sinks */
   GHashTable *cache;
-
-  /* boolean to see if we're currently switching groups */
-  gboolean group_switch;
 };
 
 struct _GstPlayBinClass
@@ -93,7 +90,6 @@ static void gst_play_bin_class_init (GstPlayBinClass * klass);
 static void gst_play_bin_init (GstPlayBin * play_bin);
 static void gst_play_bin_dispose (GObject * object);
 
-static void group_switch (GstPlayBaseBin * play_base_bin);
 static void setup_sinks (GstPlayBaseBin * play_base_bin);
 static void remove_sinks (GstPlayBin * play_bin);
 
@@ -206,7 +202,6 @@ gst_play_bin_class_init (GstPlayBinClass * klass)
   gstelement_klass->query = GST_DEBUG_FUNCPTR (gst_play_bin_query);
 
   playbasebin_klass->setup_output_pads = setup_sinks;
-  playbasebin_klass->group_switch = group_switch;
 }
 
 static void
@@ -222,7 +217,6 @@ gst_play_bin_init (GstPlayBin * play_bin)
   play_bin->frame = NULL;
   play_bin->cache = g_hash_table_new_full (g_str_hash, g_str_equal,
       NULL, (GDestroyNotify) gst_object_unref);
-  play_bin->group_switch = FALSE;
 
   /* no iterate is needed */
   GST_FLAG_SET (play_bin, GST_BIN_SELF_SCHEDULABLE);
@@ -406,7 +400,7 @@ gen_video_element (GstPlayBin * play_bin)
   if (play_bin->video_sink) {
     sink = play_bin->video_sink;
   } else {
-    sink = gst_element_factory_make (DEFAULT_VIDEOSINK, "sink");
+    sink = gst_element_factory_make ("xvimagesink", "sink");
   }
   gst_object_ref (GST_OBJECT (sink));
   g_hash_table_insert (play_bin->cache, "video_sink", sink);
@@ -435,44 +429,6 @@ done:
   return element;
 }
 
-/* make an element for playback of video with subtitles embedded.
- *
- *  +--------------------------------------------------+
- *  | tbin                  +-------------+            |
- *  |          +-----+      | textoverlay |   +------+ |
- *  |          | csp | +--video_sink      |   | vbin | |
- * video_sink-sink  src+ +-text_sink     src-sink    | |
- *  |          +-----+   |  +-------------+   +------+ |
- * text_sink-------------+                             |
- *  +--------------------------------------------------+
- */
-
-static GstElement *
-gen_text_element (GstPlayBin * play_bin)
-{
-  GstElement *element, *csp, *overlay, *vbin;
-
-  overlay = gst_element_factory_make ("textoverlay", "overlay");
-  g_object_set (G_OBJECT (overlay),
-      "halign", "center", "valign", "bottom", NULL);
-  vbin = gen_video_element (play_bin);
-  if (!overlay) {
-    g_warning ("No overlay (pango) element, subtitles disabled");
-    return vbin;
-  }
-  csp = gst_element_factory_make ("ffmpegcolorspace", "subtitlecsp");
-  element = gst_bin_new ("textbin");
-  gst_element_link_many (csp, overlay, vbin, NULL);
-  gst_bin_add_many (GST_BIN (element), csp, overlay, vbin, NULL);
-
-  gst_element_add_ghost_pad (element,
-      gst_element_get_pad (overlay, "text_sink"), "text_sink");
-  gst_element_add_ghost_pad (element,
-      gst_element_get_pad (csp, "sink"), "sink");
-
-  return element;
-}
-
 /* make the element (bin) that contains the elements needed to perform
  * audio playback. 
  *
@@ -511,7 +467,7 @@ gen_audio_element (GstPlayBin * play_bin)
   if (play_bin->audio_sink) {
     sink = play_bin->audio_sink;
   } else {
-    sink = gst_element_factory_make (DEFAULT_AUDIOSINK, "sink");
+    sink = gst_element_factory_make ("osssink", "sink");
     play_bin->audio_sink = GST_ELEMENT (gst_object_ref (GST_OBJECT (sink)));
   }
 
@@ -564,7 +520,7 @@ done:
  *  |   |  |      |                                      +-------------------+ |
  *  |   |  +------+                                                            |
  * sink-+                                                                      |
-   +--------------------------------------------------------------------------+
+ *  +--------------------------------------------------------------------------+
  */
 static GstElement *
 gen_vis_element (GstPlayBin * play_bin)
@@ -621,13 +577,6 @@ gen_vis_element (GstPlayBin * play_bin)
   return element;
 }
 
-/* set for group switch */
-static void
-group_switch (GstPlayBaseBin * play_base_bin)
-{
-  GST_PLAY_BIN (play_base_bin)->group_switch = TRUE;
-}
-
 /* get rid of all installed sinks */
 static void
 remove_sinks (GstPlayBin * play_bin)
@@ -637,7 +586,6 @@ remove_sinks (GstPlayBin * play_bin)
   GstElement *element;
 
   GST_DEBUG ("removesinks");
-  play_bin->group_switch = FALSE;
   element = g_hash_table_lookup (play_bin->cache, "abin");
   if (element != NULL) {
     parent = gst_element_get_parent (element);
@@ -685,70 +633,66 @@ remove_sinks (GstPlayBin * play_bin)
  * this should eventually be handled with a tuner interface so that
  * one can switch the streams.
  */
-static gboolean
-add_sink (GstPlayBin * play_bin, GstElement * sink, GstPad * srcpad)
-{
-  GstPad *sinkpad;
-  gboolean res;
-
-  /* we found a sink for this stream, now try to install it */
-  sinkpad = gst_element_get_pad (sink, "sink");
-  res = gst_pad_link (srcpad, sinkpad);
-  GST_DEBUG ("Adding sink with state %d (parent: %d, peer: %d)\n",
-      GST_STATE (sink), GST_STATE (play_bin),
-      GST_STATE (gst_pad_get_parent (srcpad)));
-
-  /* try to link the pad of the sink to the stream */
-  if (!res) {
-    gchar *capsstr;
-
-    /* could not link this stream */
-    capsstr = gst_caps_to_string (gst_pad_get_caps (srcpad));
-    g_warning ("could not link %s", capsstr);
-    g_free (capsstr);
-  } else {
-    /* we got the sink succesfully linked, now keep the sink
-     * in out internal list */
-    play_bin->sinks = g_list_prepend (play_bin->sinks, sink);
-    gst_bin_add (GST_BIN (play_bin), sink);
-  }
-
-  return res;
-}
-
 static void
 setup_sinks (GstPlayBaseBin * play_base_bin)
 {
   GstPlayBin *play_bin = GST_PLAY_BIN (play_base_bin);
-  GstPlayBaseGroup *group;
-  GList *streaminfo = NULL, *s;
+  GList *streaminfo;
+  GList *s;
+  gint num_audio = 0;
+  gint num_video = 0;
   gboolean need_vis = FALSE;
-  gboolean need_text = FALSE;
-  GstPad *textsrcpad = NULL, *textsinkpad = NULL;
-  GstElement *sink;
 
-  /* get rid of existing sinks */
-  if (play_bin->sinks) {
+  /* FIXME: do this nicer, like taking a look at the installed
+   * bins and figuring out if we can simply reconnect them, remove
+   * or add them. */
+  if (GST_STATE (play_base_bin) == GST_STATE_PLAYING) {
     remove_sinks (play_bin);
   }
   GST_DEBUG ("setupsinks");
+  /* get info about the stream */
+  g_object_get (G_OBJECT (play_bin), "stream-info", &streaminfo, NULL);
 
-  /* find out what to do */
-  group = play_base_bin->queued_groups->data;
-  if (group->type[GST_STREAM_TYPE_VIDEO - 1].npads > 0 &&
-      group->type[GST_STREAM_TYPE_TEXT - 1].npads > 0) {
-    need_text = TRUE;
-  } else if (group->type[GST_STREAM_TYPE_VIDEO - 1].npads == 0 &&
-      group->type[GST_STREAM_TYPE_AUDIO - 1].npads > 0 &&
-      play_bin->visualisation != NULL) {
-    need_vis = TRUE;
-  }
-
-  /* now actually connect everything */
-  g_object_get (G_OBJECT (play_base_bin), "stream-info", &streaminfo, NULL);
+  /* first examine the streams we have */
   for (s = streaminfo; s; s = g_list_next (s)) {
     GObject *obj = G_OBJECT (s->data);
     gint type;
+    GstPad *srcpad;
+
+    g_object_get (obj, "type", &type, NULL);
+    /* we don't care about streams with their own sink */
+    if (type == 4)
+      continue;
+
+    /* else we need to get the pad */
+    g_object_get (obj, "object", &srcpad, NULL);
+
+    /* hmm.. pad is allready linked */
+    if (gst_pad_is_linked (srcpad))
+      continue;
+
+    if (type == 1) {
+      num_audio++;
+    } else if (type == 2) {
+      num_video++;
+    }
+  }
+  /* no video, use vis */
+  if (num_video == 0 && num_audio > 0 && play_bin->visualisation) {
+    need_vis = TRUE;
+  }
+
+  num_audio = 0;
+  num_video = 0;
+
+  /* now actually connect everything */
+  for (s = streaminfo; s; s = g_list_next (s)) {
+    GObject *obj = G_OBJECT (s->data);
+    gint type;
+    GstPad *srcpad, *sinkpad;
+    GstElement *sink = NULL;
+    gboolean res;
+    gboolean mute = FALSE;
     GstObject *object;
 
     g_object_get (obj, "type", &type, NULL);
@@ -757,39 +701,73 @@ setup_sinks (GstPlayBaseBin * play_base_bin)
     /* use the sink elements as seek entry point */
     if (type == 4) {
       play_bin->seekables = g_list_prepend (play_bin->seekables, object);
+      continue;
     }
-  }
 
-  /* link audio */
-  if (group->type[GST_STREAM_TYPE_AUDIO - 1].npads > 0) {
-    if (need_vis) {
-      sink = gen_vis_element (play_bin);
-    } else {
-      sink = gen_audio_element (play_bin);
-    }
-    add_sink (play_bin, sink,
-        gst_element_get_pad (group->type[GST_STREAM_TYPE_AUDIO - 1].preroll,
-            "src"));
-  }
+    srcpad = GST_PAD (object);
 
-  /* link video */
-  if (group->type[GST_STREAM_TYPE_VIDEO - 1].npads > 0) {
-    if (need_text) {
-      sink = gen_text_element (play_bin);
+    /* pas is allready linked, go to the next pad */
+    if (gst_pad_is_linked (srcpad))
+      continue;
 
-      textsinkpad = gst_element_get_pad (sink, "text_sink");
-      textsrcpad =
-          gst_element_get_pad (group->type[GST_STREAM_TYPE_TEXT - 1].preroll,
-          "src");
-      if (textsinkpad && textsrcpad) {
-        gst_pad_link (textsrcpad, textsinkpad);
+    if (type == 1) {
+      if (num_audio > 0) {
+        g_warning ("two audio streams found, playing first one");
+        mute = TRUE;
+      } else {
+        if (need_vis) {
+          sink = gen_vis_element (play_bin);
+        } else {
+          sink = gen_audio_element (play_bin);
+        }
+        num_audio++;
       }
+    } else if (type == 2) {
+      if (num_video > 0) {
+        g_warning ("two video streams found, playing first one");
+        mute = TRUE;
+      } else {
+        sink = gen_video_element (play_bin);
+        num_video++;
+      }
+    } else if (type == 4) {
+      /* we can ignore these streams here */
     } else {
-      sink = gen_video_element (play_bin);
+      g_warning ("unknown stream found");
+      mute = TRUE;
+    }
+
+    /* we found a sink for this stream, now try to install it */
+    if (sink != NULL) {
+      gst_bin_add (GST_BIN (play_bin), sink);
+      GST_DEBUG ("Adding sink with state %d (parent: %d, peer: %d)\n",
+          GST_STATE (sink), GST_STATE (play_bin),
+          GST_STATE (gst_pad_get_parent (srcpad)));
+      sinkpad = gst_element_get_pad (sink, "sink");
+
+      /* try to link the pad of the sink to the stream */
+      res = gst_pad_link (srcpad, sinkpad);
+      if (!res) {
+        gchar *capsstr;
+
+        /* could not link this stream */
+        capsstr = gst_caps_to_string (gst_pad_get_caps (srcpad));
+        g_warning ("could not link %s", capsstr);
+        g_free (capsstr);
+        GST_LOG ("removing sink %p", sink);
+        gst_bin_remove (GST_BIN (play_bin), sink);
+        mute = TRUE;
+      } else {
+        /* we got the sink succesfully linked, now keep the sink
+         * in out internal list */
+        play_bin->sinks = g_list_prepend (play_bin->sinks, sink);
+      }
+    }
+    if (mute) {
+      /* no sink found/needed for this stream. We mute the stream
+       * so that it does not take any resources */
+      g_object_set (G_OBJECT (obj), "mute", TRUE, NULL);
     }
-    add_sink (play_bin, sink,
-        gst_element_get_pad (group->type[GST_STREAM_TYPE_VIDEO - 1].preroll,
-            "src"));
   }
 }
 
@@ -812,8 +790,7 @@ gst_play_bin_change_state (GstElement * element)
     case GST_STATE_PLAYING_TO_PAUSED:
       /* Set audio sink state to NULL to release the sound device,
        * but only if we own it (else we might be in chain-transition). */
-      if (play_bin->audio_sink != NULL && !play_bin->group_switch &&
-          GST_STATE (play_bin->audio_sink) == GST_STATE_PAUSED) {
+      if (GST_STATE (play_bin->audio_sink) == GST_STATE_PAUSED) {
         gst_element_set_state (play_bin->audio_sink, GST_STATE_NULL);
       }
       break;
