@@ -30,6 +30,7 @@
 
 #include <linux/em8300.h>
 
+#include <gst/gst-i18n-plugin.h>
 #include <gst/gst.h>
 
 #include "dxr3videosink.h"
@@ -48,28 +49,32 @@ static GstElementDetails dxr3videosink_details = {
 
 
 /* Dxr3VideoSink signals and args */
-enum {
+enum
+{
   SIGNAL_FLUSHED,
   LAST_SIGNAL
 };
 
-enum {
+enum
+{
   ARG_0,
 };
 
 /* Possible states for the MPEG start code scanner. */
-enum {
-  SCAN_STATE_WAITING,	/* Waiting for a code. */
-  SCAN_STATE_0,		/* 0 seen. */
-  SCAN_STATE_00,	/* 00 seen. */
-  SCAN_STATE_001	/* 001 seen. */
+enum
+{
+  SCAN_STATE_WAITING,           /* Waiting for a code. */
+  SCAN_STATE_0,                 /* 0 seen. */
+  SCAN_STATE_00,                /* 00 seen. */
+  SCAN_STATE_001                /* 001 seen. */
 };
 
 /* Possible states for the MPEG sequence parser. */
-enum {
-  PARSE_STATE_WAITING,	/* Waiting for the start of a sequence. */
-  PARSE_STATE_START,	/* Start of sequence seen. */
-  PARSE_STATE_PICTURE,	/* Picture start seen. */
+enum
+{
+  PARSE_STATE_WAITING,          /* Waiting for the start of a sequence. */
+  PARSE_STATE_START,            /* Start of sequence seen. */
+  PARSE_STATE_PICTURE           /* Picture start seen. */
 };
 
 
@@ -78,76 +83,54 @@ enum {
 #define START_CODE_SEQUENCE_HEADER 0xB3
 #define START_CODE_SEQUENCE_END 0xB7
 
-
-GST_PAD_TEMPLATE_FACTORY (dxr3videosink_sink_factory,
-  "sink",
-  GST_PAD_SINK,
-  GST_PAD_ALWAYS,
-  GST_CAPS_NEW (
-    "dxr3videosink_sink",
-    "video/mpeg",
-      "mpegversion",	GST_PROPS_LIST (
-	                  GST_PROPS_INT (1),
-	                  GST_PROPS_INT (2)
-                        ),
-      "systemstream",	GST_PROPS_BOOLEAN (FALSE)
-      /* width/height/framerate omitted, we don't
-       * need a parsed stream */
-  )
-)
+static GstStaticPadTemplate dxr3videosink_sink_factory =
+GST_STATIC_PAD_TEMPLATE ("sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("video/mpeg, "
+        "mpegversion = (int) { 1, 2 }, " "systemstream = (boolean) FALSE"
+        /* width/height/framerate omitted, we don't
+         * need a parsed stream */
+    )
+    );
 
 
-GST_PAD_EVENT_MASK_FUNCTION (dxr3videosink_get_event_mask,
-  { GST_EVENT_FLUSH, 0 },
-  { GST_EVENT_DISCONTINUOUS, 0 },
-  { GST_EVENT_EOS, 0 }
-)
+static void dxr3videosink_class_init (Dxr3VideoSinkClass * klass);
+static void dxr3videosink_base_init (Dxr3VideoSinkClass * klass);
+static void dxr3videosink_init (Dxr3VideoSink * dxr3videosink);
 
+static void dxr3videosink_set_property (GObject * object,
+    guint prop_id, const GValue * value, GParamSpec * pspec);
+static void dxr3videosink_get_property (GObject * object,
+    guint prop_id, GValue * value, GParamSpec * pspec);
 
-static void	dxr3videosink_class_init	(Dxr3VideoSinkClass *klass);
-static void	dxr3videosink_base_init		(Dxr3VideoSinkClass *klass);
-static void	dxr3videosink_init		(Dxr3VideoSink *dxr3videosink);
+static gboolean dxr3videosink_open (Dxr3VideoSink * sink);
+static void dxr3videosink_close (Dxr3VideoSink * sink);
+static void dxr3videosink_set_clock (GstElement * element, GstClock * clock);
 
-static void	dxr3videosink_set_property	(GObject *object,
-                                                 guint prop_id, 
-                                                 const GValue *value,
-                                                 GParamSpec *pspec);
-static void	dxr3videosink_get_property	(GObject *object,
-                                                 guint prop_id, 
-						 GValue *value,
-                                                 GParamSpec *pspec);
+static void dxr3videosink_reset_parser (Dxr3VideoSink * sink);
+static int dxr3videosink_next_start_code (Dxr3VideoSink * sink);
+static void dxr3videosink_discard_data (Dxr3VideoSink * sink, guint cut);
+static void dxr3videosink_write_data (Dxr3VideoSink * sink, guint cut);
+static void dxr3videosink_parse_data (Dxr3VideoSink * sink);
 
-static gboolean dxr3videosink_open		(Dxr3VideoSink *sink);
-static void 	dxr3videosink_close		(Dxr3VideoSink *sink);
-static void	dxr3videosink_set_clock		(GstElement *element,
-                                                 GstClock *clock);
+static gboolean dxr3videosink_handle_event (GstPad * pad, GstEvent * event);
+static void dxr3videosink_chain (GstPad * pad, GstData * _data);
 
-static void	dxr3videosink_reset_parser	(Dxr3VideoSink *sink);
-static int	dxr3videosink_next_start_code	(Dxr3VideoSink *sink);
-static void	dxr3videosink_discard_data	(Dxr3VideoSink *sink,
-                                                 guint cut);
-static void	dxr3videosink_write_data	(Dxr3VideoSink *sink,
-                                                 guint cut);
-static void	dxr3videosink_parse_data	(Dxr3VideoSink *sink);
-
-static gboolean dxr3videosink_handle_event	(GstPad *pad, GstEvent *event);
-static void	dxr3videosink_chain		(GstPad *pad,GstData *_data);
-
-static GstElementStateReturn dxr3videosink_change_state (GstElement *element);
+static GstElementStateReturn dxr3videosink_change_state (GstElement * element);
 
 /* static void	dxr3videosink_wait		(Dxr3VideoSink *sink, */
 /*                                                  GstClockTime time); */
-static int	dxr3videosink_mvcommand		(Dxr3VideoSink *sink,
-                                                 int command);
+static int dxr3videosink_mvcommand (Dxr3VideoSink * sink, int command);
 
-static void	dxr3videosink_flushed		(Dxr3VideoSink *sink);
+static void dxr3videosink_flushed (Dxr3VideoSink * sink);
 
 static GstElementClass *parent_class = NULL;
 static guint dxr3videosink_signals[LAST_SIGNAL] = { 0 };
 
 
 extern GType
-dxr3videosink_get_type (void) 
+dxr3videosink_get_type (void)
 {
   static GType dxr3videosink_type = 0;
 
@@ -163,9 +146,9 @@ dxr3videosink_get_type (void)
       0,
       (GInstanceInitFunc) dxr3videosink_init,
     };
+
     dxr3videosink_type = g_type_register_static (GST_TYPE_ELEMENT,
-                                                 "Dxr3VideoSink",
-                                                 &dxr3videosink_info, 0);
+        "Dxr3VideoSink", &dxr3videosink_info, 0);
   }
 
   return dxr3videosink_type;
@@ -173,34 +156,31 @@ dxr3videosink_get_type (void)
 
 
 static void
-dxr3videosink_base_init (Dxr3VideoSinkClass *klass)
+dxr3videosink_base_init (Dxr3VideoSinkClass * klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   gst_element_class_add_pad_template (element_class,
-	GST_PAD_TEMPLATE_GET (dxr3videosink_sink_factory));
-  gst_element_class_set_details (element_class,
-				 &dxr3videosink_details);
+      gst_static_pad_template_get (&dxr3videosink_sink_factory));
+  gst_element_class_set_details (element_class, &dxr3videosink_details);
 }
 
 static void
-dxr3videosink_class_init (Dxr3VideoSinkClass *klass) 
+dxr3videosink_class_init (Dxr3VideoSinkClass * klass)
 {
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
 
-  gobject_class = (GObjectClass*)klass;
-  gstelement_class = (GstElementClass*)klass;
+  gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   dxr3videosink_signals[SIGNAL_FLUSHED] =
-    g_signal_new ("flushed", G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (Dxr3VideoSinkClass, flushed),
-                  NULL, NULL,
-                  dxr3_marshal_VOID__VOID,
-                  G_TYPE_NONE, 0);
+      g_signal_new ("flushed", G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_LAST,
+      G_STRUCT_OFFSET (Dxr3VideoSinkClass, flushed),
+      NULL, NULL, dxr3_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
   klass->flushed = dxr3videosink_flushed;
 
@@ -212,19 +192,18 @@ dxr3videosink_class_init (Dxr3VideoSinkClass *klass)
 }
 
 
-static void 
-dxr3videosink_init (Dxr3VideoSink *sink) 
+static void
+dxr3videosink_init (Dxr3VideoSink * sink)
 {
   GstPad *pad;
 
-  pad = gst_pad_new_from_template (
-      GST_PAD_TEMPLATE_GET (dxr3videosink_sink_factory), "sink");
+  pad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&dxr3videosink_sink_factory), "sink");
   gst_element_add_pad (GST_ELEMENT (sink), pad);
   gst_pad_set_chain_function (pad, dxr3videosink_chain);
 
   GST_FLAG_SET (GST_ELEMENT (sink), GST_ELEMENT_EVENT_AWARE);
-  gst_pad_set_event_function (pad, dxr3videosink_handle_event);
-  gst_pad_set_event_mask_function (pad, dxr3videosink_get_event_mask);
 
   sink->card_number = 0;
 
@@ -243,8 +222,8 @@ dxr3videosink_init (Dxr3VideoSink *sink)
 
 
 static void
-dxr3videosink_set_property (GObject *object, guint prop_id,
-                            const GValue *value, GParamSpec *pspec)
+dxr3videosink_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   Dxr3VideoSink *sink;
 
@@ -258,17 +237,17 @@ dxr3videosink_set_property (GObject *object, guint prop_id,
 }
 
 
-static void   
-dxr3videosink_get_property (GObject *object, guint prop_id,
-                            GValue *value, GParamSpec *pspec)
+static void
+dxr3videosink_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec)
 {
   Dxr3VideoSink *sink;
- 
+
   /* it's not null if we got it, but it might not be ours */
   g_return_if_fail (GST_IS_DXR3VIDEOSINK (object));
- 
+
   sink = DXR3VIDEOSINK (object);
-  
+
   switch (prop_id) {
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -278,34 +257,31 @@ dxr3videosink_get_property (GObject *object, guint prop_id,
 
 
 static gboolean
-dxr3videosink_open (Dxr3VideoSink *sink)
+dxr3videosink_open (Dxr3VideoSink * sink)
 {
-  g_return_val_if_fail (!GST_FLAG_IS_SET (sink,
-                                          DXR3VIDEOSINK_OPEN), FALSE);
+  g_return_val_if_fail (!GST_FLAG_IS_SET (sink, DXR3VIDEOSINK_OPEN), FALSE);
 
   /* Compute the name of the video device file. */
   sink->video_filename = g_strdup_printf ("/dev/em8300_mv-%d",
-                                          sink->card_number );
+      sink->card_number);
 
   sink->video_fd = open (sink->video_filename, O_WRONLY);
   if (sink->video_fd < 0) {
-    gst_element_error (GST_ELEMENT (sink),
-                       g_strconcat ("Error opening device file \"",
-                                    sink->video_filename, "\": ",
-                                    g_strerror (errno), NULL));
+    GST_ELEMENT_ERROR (sink, RESOURCE, OPEN_WRITE,
+        (_("Could not open video device \"%s\" for writing."),
+            sink->video_filename), GST_ERROR_SYSTEM);
     return FALSE;
   }
 
   /* Open the control device. */
   sink->control_filename = g_strdup_printf ("/dev/em8300-%d",
-                                            sink->card_number );
+      sink->card_number);
 
   sink->control_fd = open (sink->control_filename, O_WRONLY);
   if (sink->control_fd < 0) {
-    gst_element_error (GST_ELEMENT (sink),
-                       g_strconcat ("Error opening device file \"",
-                                    sink->control_filename, "\": ",
-                                    g_strerror (errno), NULL));
+    GST_ELEMENT_ERROR (sink, RESOURCE, OPEN_WRITE,
+        (_("Could not open control device \"%s\" for writing."),
+            sink->control_filename), GST_ERROR_SYSTEM);
     return FALSE;
   }
 
@@ -316,25 +292,21 @@ dxr3videosink_open (Dxr3VideoSink *sink)
 
 
 static void
-dxr3videosink_close (Dxr3VideoSink *sink)
+dxr3videosink_close (Dxr3VideoSink * sink)
 {
   g_return_if_fail (GST_FLAG_IS_SET (sink, DXR3VIDEOSINK_OPEN));
 
-  if (close (sink->video_fd) != 0)
-  {
-    gst_element_error (GST_ELEMENT (sink),
-                       g_strconcat ("Error closing file \"",
-                                    sink->video_filename, "\": ",
-                                    g_strerror (errno), NULL));
+  if (close (sink->video_fd) != 0) {
+    GST_ELEMENT_ERROR (sink, RESOURCE, CLOSE,
+        (_("Could not close video device \"%s\"."), sink->video_filename),
+        GST_ERROR_SYSTEM);
     return;
   }
 
-  if (close (sink->control_fd) != 0)
-  {
-    gst_element_error (GST_ELEMENT (sink),
-                       g_strconcat ("Error closing file \"",
-                                    sink->control_filename, "\": ",
-                                    g_strerror (errno), NULL));
+  if (close (sink->control_fd) != 0) {
+    GST_ELEMENT_ERROR (sink, RESOURCE, CLOSE,
+        (_("Could not close control device \"%s\"."), sink->control_filename),
+        GST_ERROR_SYSTEM);
     return;
   }
 
@@ -346,7 +318,7 @@ dxr3videosink_close (Dxr3VideoSink *sink)
 
 
 static void
-dxr3videosink_set_clock (GstElement *element, GstClock *clock)
+dxr3videosink_set_clock (GstElement * element, GstClock * clock)
 {
   Dxr3VideoSink *src = DXR3VIDEOSINK (element);
 
@@ -355,7 +327,7 @@ dxr3videosink_set_clock (GstElement *element, GstClock *clock)
 
 
 static void
-dxr3videosink_reset_parser (Dxr3VideoSink *sink)
+dxr3videosink_reset_parser (Dxr3VideoSink * sink)
 {
   if (sink->cur_buf != NULL) {
     gst_buffer_unref (sink->cur_buf);
@@ -371,7 +343,7 @@ dxr3videosink_reset_parser (Dxr3VideoSink *sink)
 
 
 static int
-dxr3videosink_next_start_code (Dxr3VideoSink *sink)
+dxr3videosink_next_start_code (Dxr3VideoSink * sink)
 {
   guchar c;
 
@@ -381,31 +353,29 @@ dxr3videosink_next_start_code (Dxr3VideoSink *sink)
     c = (GST_BUFFER_DATA (sink->cur_buf))[sink->scan_pos];
 
     switch (sink->scan_state) {
-    case SCAN_STATE_WAITING:
-      if (c == 0x00) {
-        sink->scan_state = SCAN_STATE_0;
-      }
-      break;
-    case SCAN_STATE_0:
-      if (c == 0x00) {
-        sink->scan_state = SCAN_STATE_00;
-      }
-      else {
+      case SCAN_STATE_WAITING:
+        if (c == 0x00) {
+          sink->scan_state = SCAN_STATE_0;
+        }
+        break;
+      case SCAN_STATE_0:
+        if (c == 0x00) {
+          sink->scan_state = SCAN_STATE_00;
+        } else {
+          sink->scan_state = SCAN_STATE_WAITING;
+        }
+        break;
+      case SCAN_STATE_00:
+        if (c == 0x01) {
+          sink->scan_state = SCAN_STATE_001;
+        } else if (c != 0x00) {
+          sink->scan_state = SCAN_STATE_WAITING;
+        }
+        break;
+      case SCAN_STATE_001:
+        sink->scan_pos++;
         sink->scan_state = SCAN_STATE_WAITING;
-      }
-      break;
-    case SCAN_STATE_00:
-      if (c == 0x01) {
-        sink->scan_state = SCAN_STATE_001;
-      }
-      else if (c != 0x00) { 
-        sink->scan_state = SCAN_STATE_WAITING;
-      }
-      break;
-    case SCAN_STATE_001:
-      sink->scan_pos++;
-      sink->scan_state = SCAN_STATE_WAITING;
-      return c;
+        return c;
     }
 
     sink->scan_pos++;
@@ -416,7 +386,7 @@ dxr3videosink_next_start_code (Dxr3VideoSink *sink)
 
 
 static void
-dxr3videosink_discard_data (Dxr3VideoSink *sink, guint cut)
+dxr3videosink_discard_data (Dxr3VideoSink * sink, guint cut)
 {
   GstBuffer *sub;
   guint size;
@@ -431,11 +401,10 @@ dxr3videosink_discard_data (Dxr3VideoSink *sink, guint cut)
   if (GST_BUFFER_SIZE (sink->cur_buf) == size) {
     gst_buffer_unref (sink->cur_buf);
     sink->cur_buf = NULL;
-  }
-  else {
+  } else {
     sub = gst_buffer_create_sub (sink->cur_buf, size,
-                                 GST_BUFFER_SIZE (sink->cur_buf)
-                                 - size);
+        GST_BUFFER_SIZE (sink->cur_buf)
+        - size);
     gst_buffer_unref (sink->cur_buf);
     sink->cur_buf = sub;
   }
@@ -448,7 +417,7 @@ dxr3videosink_discard_data (Dxr3VideoSink *sink, guint cut)
 
 
 static void
-dxr3videosink_write_data (Dxr3VideoSink *sink, guint cut)
+dxr3videosink_write_data (Dxr3VideoSink * sink, guint cut)
 {
   guint size, written;
   guint8 *data;
@@ -480,8 +449,9 @@ dxr3videosink_write_data (Dxr3VideoSink *sink, guint cut)
     while (size > 0) {
       written = write (sink->video_fd, data, size);
       if (written < 0) {
-        gst_element_error (GST_ELEMENT (sink), "Writing to %s: %s",
-                           sink->video_filename, strerror (errno));
+        GST_ELEMENT_ERROR (sink, RESOURCE, WRITE,
+            (_("Could not write to device \"%s\"."), sink->video_filename),
+            GST_ERROR_SYSTEM);
         break;
       }
       size = size - written;
@@ -494,7 +464,7 @@ dxr3videosink_write_data (Dxr3VideoSink *sink, guint cut)
 
 
 static void
-dxr3videosink_parse_data (Dxr3VideoSink *sink)
+dxr3videosink_parse_data (Dxr3VideoSink * sink)
 {
   int code;
 
@@ -506,46 +476,46 @@ dxr3videosink_parse_data (Dxr3VideoSink *sink)
   while (code >= 0) {
     switch (sink->parse_state) {
 
-    case PARSE_STATE_WAITING:
-      if (code == START_CODE_SEQUENCE_HEADER) {
-        dxr3videosink_discard_data (sink, 4);
-        sink->parse_state = PARSE_STATE_START;
-        sink->cur_ts = sink->last_ts;
-      }
-      break;
+      case PARSE_STATE_WAITING:
+        if (code == START_CODE_SEQUENCE_HEADER) {
+          dxr3videosink_discard_data (sink, 4);
+          sink->parse_state = PARSE_STATE_START;
+          sink->cur_ts = sink->last_ts;
+        }
+        break;
 
-    case PARSE_STATE_START:
-      switch (code) {
-      case START_CODE_SEQUENCE_HEADER:
-        dxr3videosink_discard_data (sink, 4);
-        sink->cur_ts = sink->last_ts;
+      case PARSE_STATE_START:
+        switch (code) {
+          case START_CODE_SEQUENCE_HEADER:
+            dxr3videosink_discard_data (sink, 4);
+            sink->cur_ts = sink->last_ts;
+            break;
+          case START_CODE_SEQUENCE_END:
+            dxr3videosink_discard_data (sink, 0);
+            sink->parse_state = PARSE_STATE_WAITING;
+            break;
+          case START_CODE_PICTURE:
+            sink->parse_state = PARSE_STATE_PICTURE;
+            break;
+        }
         break;
-      case START_CODE_SEQUENCE_END:
-        dxr3videosink_discard_data (sink, 0);
-        sink->parse_state = PARSE_STATE_WAITING;
-        break;
-      case START_CODE_PICTURE:
-        sink->parse_state = PARSE_STATE_PICTURE;
-        break;
-      }
-      break;
 
-    case PARSE_STATE_PICTURE:
-      switch (code) {
-      case START_CODE_SEQUENCE_HEADER:
-        dxr3videosink_write_data (sink, 4);
-        sink->parse_state = PARSE_STATE_START;
-        sink->cur_ts = sink->last_ts;
+      case PARSE_STATE_PICTURE:
+        switch (code) {
+          case START_CODE_SEQUENCE_HEADER:
+            dxr3videosink_write_data (sink, 4);
+            sink->parse_state = PARSE_STATE_START;
+            sink->cur_ts = sink->last_ts;
+            break;
+          case START_CODE_SEQUENCE_END:
+            dxr3videosink_write_data (sink, 0);
+            sink->parse_state = PARSE_STATE_WAITING;
+            break;
+          case START_CODE_PICTURE:
+            dxr3videosink_write_data (sink, 4);
+            break;
+        }
         break;
-      case START_CODE_SEQUENCE_END:
-        dxr3videosink_write_data (sink, 0);
-        sink->parse_state = PARSE_STATE_WAITING;
-        break;
-      case START_CODE_PICTURE:
-        dxr3videosink_write_data (sink, 4);
-        break;
-      }
-      break;
 
     }
 
@@ -559,7 +529,7 @@ dxr3videosink_parse_data (Dxr3VideoSink *sink)
 
 
 static gboolean
-dxr3videosink_handle_event (GstPad *pad, GstEvent *event)
+dxr3videosink_handle_event (GstPad * pad, GstEvent * event)
 {
   GstEventType type;
   Dxr3VideoSink *sink;
@@ -569,8 +539,8 @@ dxr3videosink_handle_event (GstPad *pad, GstEvent *event)
   type = event ? GST_EVENT_TYPE (event) : GST_EVENT_UNKNOWN;
 
   switch (type) {
-  case GST_EVENT_EMPTY:
-    //fprintf (stderr, "++++++ Video empty event\n");
+    case GST_EVENT_EMPTY:
+      //fprintf (stderr, "++++++ Video empty event\n");
     {
       /* FIXME: Handle this with a discontinuity or something. */
       /* Write an MPEG2 sequence end code, to ensure that the card
@@ -584,18 +554,16 @@ dxr3videosink_handle_event (GstPad *pad, GstEvent *event)
 
       write (sink->video_fd, &sec, 4);
     }
-    break;
+      break;
 
-  case GST_EVENT_DISCONTINUOUS:
-    //fprintf (stderr, "++++++ Video discont event\n");
+    case GST_EVENT_DISCONTINUOUS:
+      //fprintf (stderr, "++++++ Video discont event\n");
     {
       gint64 time;
       gboolean has_time;
       unsigned cur_scr, mpeg_scr, diff;
 
-      has_time = gst_event_discont_get_value (event,
-                                              GST_FORMAT_TIME,
-                                              &time);
+      has_time = gst_event_discont_get_value (event, GST_FORMAT_TIME, &time);
       if (has_time) {
 /*         fprintf (stderr, "^^^^^^ Discontinuous event has time %.4f\n", */
 /*                  (double) time / GST_SECOND); */
@@ -607,33 +575,33 @@ dxr3videosink_handle_event (GstPad *pad, GstEvent *event)
         diff = cur_scr > mpeg_scr ? cur_scr - mpeg_scr : mpeg_scr - cur_scr;
         if (diff > 1800) {
           unsigned zero = 0;
+
 /*           fprintf (stderr, "====== Adjusting SCR from video\n"); */
 
           ioctl (sink->control_fd, EM8300_IOCTL_SCR_SET, &zero);
           ioctl (sink->control_fd, EM8300_IOCTL_SCR_SET, &mpeg_scr);
         }
-      }
-      else {
+      } else {
 /*         fprintf (stderr, "^^^^^^ Discontinuous event has no time\n"); */
       }
     }
-    break;
+      break;
 
-  case GST_EVENT_FLUSH:
-    dxr3videosink_reset_parser (sink);
-    break;
+    case GST_EVENT_FLUSH:
+      dxr3videosink_reset_parser (sink);
+      break;
 
-  default:
-    gst_pad_event_default (pad, event);
-    break;
+    default:
+      gst_pad_event_default (pad, event);
+      break;
   }
 
   return TRUE;
 }
 
 
-static void 
-dxr3videosink_chain (GstPad *pad, GstData *_data) 
+static void
+dxr3videosink_chain (GstPad * pad, GstData * _data)
 {
   GstBuffer *buf = GST_BUFFER (_data);
   Dxr3VideoSink *sink;
@@ -654,8 +622,7 @@ dxr3videosink_chain (GstPad *pad, GstData *_data)
 
   if (sink->cur_buf == NULL) {
     sink->cur_buf = buf;
-  }
-  else {
+  } else {
     merged = gst_buffer_merge (sink->cur_buf, buf);
     gst_buffer_unref (sink->cur_buf);
     gst_buffer_unref (buf);
@@ -669,7 +636,7 @@ dxr3videosink_chain (GstPad *pad, GstData *_data)
 
 
 static GstElementStateReturn
-dxr3videosink_change_state (GstElement *element)
+dxr3videosink_change_state (GstElement * element)
 {
   g_return_val_if_fail (GST_IS_DXR3VIDEOSINK (element), GST_STATE_FAILURE);
 
@@ -713,7 +680,7 @@ dxr3videosink_change_state (GstElement *element)
  * Make the sink wait the specified amount of time.
  */
 static void
-dxr3videosink_wait (Dxr3VideoSink *sink, GstClockTime time)
+dxr3videosink_wait (Dxr3VideoSink * sink, GstClockTime time)
 {
   GstClockID id;
   GstClockTimeDiff jitter;
@@ -732,14 +699,14 @@ dxr3videosink_wait (Dxr3VideoSink *sink, GstClockTime time)
  * Send an MVCOMMAND to the card.
  */
 static int
-dxr3videosink_mvcommand (Dxr3VideoSink *sink, int command)
+dxr3videosink_mvcommand (Dxr3VideoSink * sink, int command)
 {
   em8300_register_t regs;
-  
+
   regs.microcode_register = 1;
   regs.reg = 0;
   regs.val = command;
-  
+
   return ioctl (sink->control_fd, EM8300_IOCTL_WRITEREG, &regs);
 }
 
@@ -752,7 +719,7 @@ dxr3videosink_mvcommand (Dxr3VideoSink *sink, int command)
  * queues due to a received flush event 
  */
 static void
-dxr3videosink_flushed (Dxr3VideoSink *sink)
+dxr3videosink_flushed (Dxr3VideoSink * sink)
 {
   /* Do nothing. */
 }
