@@ -123,8 +123,10 @@ gst_v4l2_fill_lists (GstV4l2Element * v4l2element)
           g_object_unref (G_OBJECT (channel));
           return FALSE;
         }
-        channel->min_frequency = vtun.rangelow;
-        channel->max_frequency = vtun.rangehigh;
+        channel->freq_multiplicator =
+            62.5 * ((vtun.capability & V4L2_TUNER_CAP_LOW) ? 1 : 1000);
+        channel->min_frequency = vtun.rangelow * channel->freq_multiplicator;
+        channel->max_frequency = vtun.rangehigh * channel->freq_multiplicator;
         channel->min_signal = 0;
         channel->max_signal = 0xffff;
       }
@@ -357,15 +359,18 @@ gst_v4l2_set_defaults (GstV4l2Element * v4l2element)
     gst_tuner_channel_changed (tuner, channel);
     g_object_notify (G_OBJECT (v4l2element), "channel");
   }
-  if (v4l2element->frequency != 0) {
-    gst_tuner_set_frequency (tuner, channel, v4l2element->frequency);
-  } else {
-    v4l2element->frequency = gst_tuner_get_frequency (tuner, channel);
-    if (v4l2element->frequency == 0) {
-      /* guess */
-      gst_tuner_set_frequency (tuner, channel, 1000);
+
+  if (GST_TUNER_CHANNEL_HAS_FLAG (channel, GST_TUNER_CHANNEL_FREQUENCY)) {
+    if (v4l2element->frequency != 0) {
+      gst_tuner_set_frequency (tuner, channel, v4l2element->frequency);
     } else {
-      g_object_notify (G_OBJECT (v4l2element), "frequency");
+      v4l2element->frequency = gst_tuner_get_frequency (tuner, channel);
+      if (v4l2element->frequency == 0) {
+        /* guess */
+        gst_tuner_set_frequency (tuner, channel, 1000);
+      } else {
+        g_object_notify (G_OBJECT (v4l2element), "frequency");
+      }
     }
   }
 }
@@ -620,10 +625,13 @@ gst_v4l2_get_frequency (GstV4l2Element * v4l2element,
     gint tunernum, gulong * frequency)
 {
   struct v4l2_frequency freq;
+  GstTunerChannel *channel;
 
   DEBUG ("getting current tuner frequency");
   GST_V4L2_CHECK_OPEN (v4l2element);
 
+  channel = gst_tuner_get_channel (GST_TUNER (v4l2element));
+
   freq.tuner = tunernum;
   if (ioctl (v4l2element->video_fd, VIDIOC_G_FREQUENCY, &freq) < 0) {
     GST_ELEMENT_ERROR (v4l2element, RESOURCE, SETTINGS, (NULL),
@@ -632,7 +640,7 @@ gst_v4l2_get_frequency (GstV4l2Element * v4l2element,
     return FALSE;
   }
 
-  *frequency = freq.frequency;
+  *frequency = freq.frequency * channel->freq_multiplicator;
 
   return TRUE;
 }
@@ -649,15 +657,18 @@ gst_v4l2_set_frequency (GstV4l2Element * v4l2element,
     gint tunernum, gulong frequency)
 {
   struct v4l2_frequency freq;
+  GstTunerChannel *channel;
 
   DEBUG ("setting current tuner frequency to %lu", frequency);
   GST_V4L2_CHECK_OPEN (v4l2element);
   GST_V4L2_CHECK_NOT_ACTIVE (v4l2element);
 
+  channel = gst_tuner_get_channel (GST_TUNER (v4l2element));
+
   freq.tuner = tunernum;
   /* fill in type - ignore error */
   ioctl (v4l2element->video_fd, VIDIOC_G_FREQUENCY, &freq);
-  freq.frequency = frequency;
+  freq.frequency = frequency / channel->freq_multiplicator;
 
   if (ioctl (v4l2element->video_fd, VIDIOC_S_FREQUENCY, &freq) < 0) {
     GST_ELEMENT_ERROR (v4l2element, RESOURCE, SETTINGS, (NULL),
